@@ -31,7 +31,7 @@ use NetAddr::IP::Util qw(
 
 use vars qw(@ISA @EXPORT_OK $VERSION $Accept_Binary_IP $Old_nth $AUTOLOAD *Zero);
 
-$VERSION = do { my @r = (q$Revision: 1.37 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.38 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 require Exporter;
 
@@ -717,16 +717,6 @@ sub _no_octal {
   return sprintf("%d.%d.%d.%d",$1,$2,$3,$4);
 }
 
-# function to stringify various flavors of Math::BigInt objects
-# tests to see if the object is a hash or a signed scalar
-#
-sub retMBIstring {
-  local *MBI = $_[0];
-  return (defined *MBI{HASH})           # recent version ?
-        ? join('',reverse @{$_[0]->{value}})
-        : do { ${$_[0]} =~ /(\d+)/; $1 };
-}
-
 sub _xnew($$;$$) {
   my $noctal	= 0;
   my $isV6	= shift;
@@ -739,7 +729,7 @@ sub _xnew($$;$$) {
   my $ip	= shift;
 
   $ip = 'default' unless defined $ip;
-  $ip = retMBIstring($ip)		# treat as big bcd string
+  $ip = _retMBIstring($ip)		# treat as big bcd string
 	if ref $ip && ref $ip eq 'Math::BigInt';	# can /CIDR notation
   my $hasmask = 1;
   my($mask,$tmp);
@@ -813,7 +803,7 @@ sub _xnew($$;$$) {
 # if either of the above conditions is true, $try contains the NetAddr 128 bit address
 
 # checkfor Math::BigInt mask
-    $mask = retMBIstring($mask)				# treat as big bcd string
+    $mask = _retMBIstring($mask)				# treat as big bcd string
         if ref $mask && ref $mask eq 'Math::BigInt';
 
 # MASK to lower case AFTER ref test for Math::BigInt, 'lc' strips blessing
@@ -1207,38 +1197,63 @@ netmask.
 
 =cut
 
-# as of this writing there are three known flavors of Math::BigInt
-# v0.01		MBI::new returns a scalar ref
-# v1.?? - 1.69	CALC::_new takes a reference to a scalar, returns an array, MBI returns a hash ref
-# v1.70 and up	CALC::_new takes a scalar, returns and array, MBI returns a hash ref
-
 my $biloaded;
+my $bi2strng;
 my $no_mbi_emu = 1;
 
 # function to force into test development mode
 #
 sub _force_bi_emu {
   undef $biloaded;
+  undef $bi2strng;
   $no_mbi_emu = 0;
-  print STDERR "\n\n\tWARNING: test development mode, this 
+  print STDERR "\n\n\tWARNING: test development mode, this
 \tmessage SHOULD NEVER BE SEEN IN PRODUCTION!
 set my \$no_mbi_emu = 1 in t/bigint.t to remove this warning\n\n";
 }
 
-# from bi string like Math::BigInt 0.01
+# function to stringify various flavors of Math::BigInt objects
+# tests to see if the object is a hash or a signed scalar
+
+sub _bi_stfy {
+  "$_[0]" =~ /(\d+)/;		# stringify and remove '+' if present
+  $1;
+}
+
+sub _fakebi2strg {
+  ${$_[0]} =~ /(\d+)/;
+  $1;
+}
+
+# fake new from bi string Math::BigInt 0.01
 #
 sub _bi_fake {
   bless \('+'. $_[1]), 'Math::BigInt';
 }
 
-sub _biRef {
-  unless ($biloaded) {					# load Math::BigInt on demand
-    if (eval {$no_mbi_emu && require Math::BigInt}) {	# any version should work, three known
-      $biloaded = \&Math::BigInt::new;
-    } else {
-      $biloaded = \&_bi_fake;
-    }
+# as of this writing there are three known flavors of Math::BigInt
+# v0.01         MBI::new returns a scalar ref
+# v1.?? - 1.69  CALC::_new takes a reference to a scalar, returns an array, MBI returns a hash ref
+# v1.70 and up  CALC::_new takes a scalar, returns and array, MBI returns a hash ref
+
+sub _loadMBI {						# load Math::BigInt on demand
+  if (eval {$no_mbi_emu && require Math::BigInt}) {	# any version should work, three known
+    import Math::BigInt;
+    $biloaded = \&Math::BigInt::new;
+    $bi2strng = \&_bi_stfy;
+  } else {
+    $biloaded = \&_bi_fake;
+    $bi2strng = \&_fakebi2strg;
   }
+}
+
+sub _retMBIstring {
+  _loadMBI unless $biloaded;				# load Math::BigInt on demand
+  $bi2strng->(@_);
+}
+
+sub _biRef {
+  _loadMBI unless $biloaded;				# load Math::BigInt on demand
   $biloaded->('Math::BigInt',$_[0]);
 }
 
